import sys
import aetros

if __name__ == '__main__':
    sys.exit(aetros.main())